@ECHO OFF

REM ***************************************************************************************
REM Batch File for Automatic Batch Conversion using File Conversion Center Professional and
REM the Windows Task Scheduler
REM
REM THIS CODE AND INFORMATION IS PROVIDED 'AS IS' WITHOUT WARRANTY OF ANY KIND, EITHER
REM EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF 
REM MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
REM
REM Author: PEERNET Inc. (c) 2010-2014
REM
REM ***************************************************************************************

REM ***************************************************************************************
REM Variables used in batch file
REM 1. Current directory
REM 2. Put File Conversion Center Professional into the PATH environment variable
REM ***************************************************************************************

REM ---------------------------------------------------------------------------------------
REM 1. Current directory from which the batch file is running
REM 
ECHO Setting current directory to %CD%
set CURDIR=%CD%

REM ---------------------------------------------------------------------------------------

REM ---------------------------------------------------------------------------------------
REM 2. This adds the path to File Conversion Center Professional to the PATH environment variable.
REM This lets us call File Conversion Center Professional without having to specify the 
REM full path to the executable.
REM 

ECHO Setting Path environment
set OLDPATH=%PATH%
set PATH=%PATH%;%ProgramFiles%\PEERNET File Conversion Center 6.0\



REM ---------------------------------------------------------------------------------------


REM ***************************************************************************************
REM Checking for the required folders:
REM     1. Check for the folders \INPUT and \OUTPUT; exit if they do not exist.
REM     2. Check for \STAGING folder; if this folder exists, a previous instance of this is
REM        running and we will exit. If it does not exist, create it and continue.
REM ***************************************************************************************

REM ---------------------------------------------------------------------------------------
REM 1. Check for \INPUT and \OUTPUT
REM

REM ECHO Test for INPUT and OUTPUT folders
REM IF NOT EXIST "%CURDIR%"\INPUT\ GOTO MISSINGFOLDERS
REM IF NOT EXIST "%CURDIR%"\OUTPUT\ GOTO MISSINGFOLDERS



REM ---------------------------------------------------------------------------------------

REM ---------------------------------------------------------------------------------------
REM 2. Check for %CURDIR\STAGING folder. If this folder exists, a previous instance of this
REM batch file is running. If it does not exist, create it and continue.
REM 
ECHO Test for STAGING folders to see if batch is already running
IF EXIST "%CURDIR%"\STAGING\nul GOTO RUNNING
MKDIR "%CURDIR%"\STAGING\



REM ---------------------------------------------------------------------------------------


REM ***************************************************************************************
REM Move any input files into the staging folder
REM NOTE: This will overwrite any existing input files in the folder.
REM If there are no files to move, skip processing.
REM ***************************************************************************************
REM
ECHO Move input files to STAGING folder
MOVE /Y "%CURDIR%"\INPUT\*.* "%CURDIR%"\STAGING\
IF "%ERRORLEVEL%"=="1" GOTO NOFILES



REM ***************************************************************************************
REM Call File Conversion Center Professional to process the files.

REM Using DOSFCC6.exe will cause the batch file to stop and wait for the conversion to 
REM complete before returning. This allows for the following lines to perform some custom
REM actions on the newly created files, such as uploading to a document archiving system
REM or copying to another location.

REM The command line arguments are:
REM 
REM /R /X - show progress dialog and auto-close when files are converted
REM /P=Fax(TIFF) - create fax format TIFF images using predefined conversion settings
REM /L="%CURDIR%\autoconvert.log,a" - create log file, append to any existing log file
REM /O="%CURDIR%\OUPUT\" - create output files in this folder
REM "%CURDIR%\STAGING\" - process files from this folder
REM 
REM ***************************************************************************************
ECHO Calling File Conversion Center Professional DOSFCC6.exe /R /X /P=Fax(TIFF) /L="%CURDIR%\autoconvert.log,a" /O="%CURDIR%\OUTPUT\" "%CURDIR%\STAGING\"
DOSFCC6.exe /R /X /P=Fax(TIFF) /L="%CURDIR%\autoconvert.log,a" /O="%CURDIR%\OUTPUT\" "%CURDIR%\STAGING\"



REM ---------------------------------------------------------------------------------------
REM Comment out the previous call and uncomment the following to have the conversion run
REM silently without any dialogs 
REM 
REM /Q - run silent with no progress dialog 
REM /N - suppress error messages and dialogs
REM 
REM ECHO Calling File Conversion Center Professional DOSFCC6.exe /Q /N /P=Fax(TIFF) /L="%CURDIR%\autoconvert.log,a" /O="%CURDIR%\OUTPUT\" "%CURDIR%\STAGING\"
REM DOSFCC6.exe /Q /N /P=Fax(TIFF) /L="%CURDIR%\autoconvert.log,a" /O="%CURDIR%\OUTPUT\" "%CURDIR%\STAGING\"
REM ---------------------------------------------------------------------------------------


REM ***************************************************************************************
REM ******** THIS IS WHERE YOU WOULD DO ANY CUSTOM PROCESSING OF THE OUTPUT FILES. ********
REM
REM In this sample the new files are copied to a new folder, along with the source files
REM and the log and results files created by File Conversion Center Professional.
REM 
REM 1. Get the name of the folder based on the current date and time.
REM 2. Create <date_time> and <date_time>_source folders
REM 3. Copy the new files, log file and results file to <date_time>
REM 4. Copy the orignal source files files to the <date_time>_source
REM 
REM ***************************************************************************************

REM ---------------------------------------------------------------------------------------
REM 1. Get date and time stamp for folder name
REM
REM Date formatting may be different depending on you regional settings.
REM Replace any spaces and '/' with '_'; this eliminates the problem of the date being
REM formatted differently on different operatings systems.
REM Wed 25/02/2010 will become Wed_25_02_2010
REM 25/02/2010 will become 25_02_2010
set DATESTAMP=%DATE%
set DATESTAMP=%DATESTAMP: =_%
set DATESTAMP=%DATESTAMP:/=_%

REM For a time formatted as 12:12:00.00, strip out the hour_minute_second
set TIMESTAMP=%TIME:~0,2%_%TIME:~3,2%_%TIME:~6,2%

REM Remove any spaces and concatenate 
set DATEANDTIME=%DATESTAMP: =%_%TIMESTAMP: =%

REM ---------------------------------------------------------------------------------------


REM ---------------------------------------------------------------------------------------
REM 2. Create the folders <date_time> and <date_time>_source
ECHO Creating current run output folders
set OUTDIR="%CURDIR%"\%DATEANDTIME%
mkdir %OUTDIR%
set COPYSOURCE="%CURDIR%"\%DATEANDTIME%_source
mkdir %COPYSOURCE%

REM ---------------------------------------------------------------------------------------

REM ---------------------------------------------------------------------------------------
REM 3. Move new TIFF images, log file and results file to the <date_time> folder
REM 
ECHO Moving output, log file and results file to the current run output folders
MOVE /Y "%CURDIR%"\OUTPUT\*.tif %OUTDIR%
MOVE "%CURDIR%"\autoconvert.log %OUTDIR%
MOVE "%CURDIR%"\autoconvertResults.txt %OUTDIR%

REM ---------------------------------------------------------------------------------------

REM ---------------------------------------------------------------------------------------
REM 4. Move the source files to the <date_time>_source folder
REM 
ECHO Move the source files to the current run source folder
MOVE /Y "%CURDIR%"\STAGING\*.* %COPYSOURCE%

REM ---------------------------------------------------------------------------------------


REM ***************************************************************************************
REM All done, go to cleanup section
REM ***************************************************************************************
GOTO CLEANUP


REM ***************************************************************************************
REM If we get here, the \INPUT and \OUTPUT folders are missing
REM ***************************************************************************************
:MISSINGFOLDERS
ECHO Missing INPUT and OUTPUT folders

GOTO CLEANUP


REM ***************************************************************************************
REM If we get here, there were no input files
REM ***************************************************************************************
:NOFILES
ECHO No files found to process


:CLEANUP
REM ***************************************************************************************
REM Delete staging and contents
REM ***************************************************************************************
ECHO Cleaning up
RMDIR /S /Q "%CURDIR%"\STAGING
GOTO END


REM ***************************************************************************************
REM If we get here, the batch file has been called while a previous instance 
REM is still running. 
REM ***************************************************************************************
:RUNNING 
ECHO The program is running
GOTO END

:END

REM ***************************************************************************************
REM Clear any environment variables we set
REM ***************************************************************************************
ECHO Clearing environment variables
set CURDIR=
set DATESTAMP=
set TIMESTAMP=
set DATEANDTIME=
set OUTDIR=
set OLDPATH=